Welcome to SpiceyPy's documentation!
====================================

This is the documentation for SpiceyPy. The documentation for each
function in the wrapper is in large part copied from the "Abstract"
and "Brief_I/O" sections of the corresponding CSPICE function documentation.
Each wrapper function has a link back to the corresponding original CSPICE
function documentation hosted at the NAIF website. For more in-depth information
about SPICE, please visit the NAIF website or
`click here <http://naif.jpl.nasa.gov/pub/naif/toolkit_docs/C/>`_
to view the entire CSPICE documentation.

The intent of the function doc-strings is to serve only as a quick reference to
what the parameter's expected types are for the purpose of getting started with
the wrapper. As each function has a link to the CSPICE documentation for that
function, more detailed explanations are deferred to the NAIF via those links.

Contents:

.. toctree::
   :maxdepth: 2

   installation
   exampleone
   lessonindex
   documentation


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

